cppy: C++ headers for C extension development
===========================================================================

Description
-----------

From: https://pypi.org/project/cppy/

A small C++ header library which makes it easier to write Python extension
modules. The primary feature is a PyObject smart pointer which automatically
handles reference counting and provides convenience methods for performing
common object operations.

License
-------

Modified BSD 3-Clause-License

Upstream Contact
----------------

https://github.com/nucleic/cppy
